@@ -96,9 +96,12 @@ public enum FixedCode implements ReportCode {
     E_JDNO( "Missing job document" ),
     E_JDPH( "Info/phase phase mismatch" ),
     E_JDSX( "Error parsing job document" ),
+    E_JREJ( "Async job rejected before RUN" ),
     E_KCIO( "Error reading TAP_SCHEMA.key_columns table" ),
     E_KEYX( "Unknown standard language feature key" ),
     E_LVER( "Some ADQL variants fail" ),
+    E_LNUL( "Illegal ObsPlan NULLs" ),
+    E_LNSP( "Illegal ObsPlan NULL times" ),
     E_MCOL( "Query/result column count mismatch" ),
     E_MUPM( "Missing mandatory upload declaration" ),
     E_NAKT( "Table elements outside of any Schema" ),
@@ -119,10 +122,33 @@ public enum FixedCode implements ReportCode {
     E_PAMM( "Bad job parameter value" ),
     E_PANO( "Nameless parameter" ),
     E_PANZ( "Non-blank job parameter" ),
+    E_PCOL( "Missing ObsLocTAP column" ),
+    E_PCMS( "Incorrect obsplan column type" ),
     E_PHUR( "Incorrect phase" ),
+    E_PLUT( "ObsLocTAP table wrong utype" ),
+    E_PN0C( "Epn_core missing column" ),
+    E_PN86( "Epn_core bad timestamp" ),
+    E_PNDE( "Incorrect epn_core column type" ),
+    E_PNDP( "Epn_core dataproduct_type bad values" ),
+    E_PNFT( "Epn_core spatial_frame_type bad values" ),
+    E_PNGT( "Epn_core geometry_type bad values" ),
+    E_PNIK( "Bad InchiKey syntax" ),
+    E_PNLT( "Epn_core local_time out of range" ),
+    E_PNTN( "Epn_core table wrong name" ),
+    E_PNMM( "Epn_core min/max constraints violated" ),
+    E_PNMX( "Epn_core min/max columns not paired" ),
+    E_PNPL( "Illegal epn_core processing_level" ),
+    E_PNST( "Service title not equal to schema" ),
+    E_PNTG( "Illegal epn_core target_class" ),
+    E_PNUL( "Illegal epn_core NULLs" ),
+    E_PNUT( "Epn_core table wrong utype" ),
+    E_PNMG( "Epn_core bad messenger" ),
+    E_PNXT( "Wrong xtype for epn_core column" ),
     E_POER( "POST failure" ),
     E_PORE( "POST error" ),
+    E_PPST( "Epn_core particle_spectral_type bad values" ),
     E_PTXT( "Non plain-text RDFa property content" ),
+    E_PVAL( "Illegal ObsLocTAP cell value" ),
     E_QERR( "Query failed" ),
     E_QERX( "Query result parse error" ),
     E_QFAA( "Query failure" ),
@@ -136,6 +162,8 @@ public enum FixedCode implements ReportCode {
     E_RUPH( "Bad phase for started job" ),
     E_SCIO( "Error reading TAP_SCHEMA.schemas table" ),
     E_SPPA( "Spurious query parameter breaks query" ),
+    E_SRXT( "Wrong xtype for s_region" ),
+    E_SVRB( "Bad HTTP Server header syntax" ),
     E_TADH( "Tables endpoint declaration/presence mismatch" ),
     E_TBIO( "Error reading TAP_SCHEMA.tables table" ),
     E_TMCD( "Upload result column value mismatch" ),
@@ -156,6 +184,7 @@ public enum FixedCode implements ReportCode {
     E_TSNL( "Null values in non-nullable column" ),
     E_TTOO( "Multiple result TABLEs" ),
     E_TYPX( "ObsCore datatype incompatibilty" ),
+    E_UCDX( "Bad UCD" ),
     E_UDFE( "Bad UDF declaration" ),
     E_UKTB( "Unknown table referenced in example" ),
     E_UPBD( "Unknown upload suffix" ),
@@ -184,6 +213,7 @@ public enum FixedCode implements ReportCode {
     W_CPSM( "Unknown security method ID" ),
     W_CPUL( "Non-standard access URL for standard interface" ),
     W_CPUR( "Service and declared TAP base URL mismatch" ),
+    W_CRGN( "Unknown DALI region xtype" ),
     W_CTYP( "Datatype possible mismatch" ),
     W_CUCD( "UCD mismatch" ),
     W_CULF( "Custom language feature type" ),
@@ -191,6 +221,10 @@ public enum FixedCode implements ReportCode {
     W_CUTP( "UType mismatch" ),
     W_DMDC( "DataModel not declared" ),
     W_DMSS( "DataModel subset undeclared" ),
+    W_DRUC( "Declared/result UCD mismatch" ),
+    W_DRUN( "Declared/result unit mismatch" ),
+    W_DRUT( "Declared/result UType mismatch" ),
+    W_DRXT( "Declared/result XType mismatch" ),
     W_DQU2( "Unknown value for post-table QUERY_STATUS" ),
     W_EX00( "No examples in examples document" ),
     W_EXUL( "Undeclared query language" ),
@@ -209,20 +243,34 @@ public enum FixedCode implements ReportCode {
     W_NOCT( "Missing Content-Type header" ),
     W_NOMS( "No error message text" ),
     W_NSOP( "ObsCore value not in suggested set" ),
+    W_OLNG( "Bad LANG not rejected" ),
+    W_PGEO( "Undeclared required geometry functions" ),
+    W_PNJD( "Implausible Julian Day" ),
+    W_PNTS( "Non-standard timescale" ),
+    W_PNUB( "Transitional EPN-TAP utype" ),
     W_QERR( "Query failed" ),
     W_QTYP( "Query/result column type possible mismatch" ),
     W_RDIO( "Resource read error" ),
     W_SPPA( "Spurious query parameter changes result" ),
+    W_SVR0( "No Server HTTP header" ),
+    W_SVRV( "No VO components in Server HTTP header" ),
+    W_SPUC( "Epn_core spatial UCD mismatch" ),
+    W_SPUN( "Epn_core spatial unit mismatch" ),
     W_TADH( "Tables endpoint declaration/presence mismatch" ),
     W_TBNF( "Tables endpoint missing" ),
     W_TBUN( "Tables content" ),
     W_TFMT( "Non-ISO-8601 result" ),
+    W_TSCT( "Questionable type for TAP_SCHEMA column" ),
     W_TSDL( "Bad time format in table data" ),
     W_TSZ1( "Single-element array declared" ),
     W_TYPI( "ObsCore datatype mismatch" ),
+    W_UCDQ( "Questionable UCD" ),
     W_UNPH( "UNKNOWN phase" ),
     W_UNSC( "Foreign schema used in validation" ),
     W_UPCS( "Custom upload method" ),
+    W_VUNE( "Unit is not legal VOUnit" ),
+    W_VUNR( "Unit is not recommended VOUnit" ),
+    W_VCPD( "Preliminary/deprecated vocabulary term" ),
     W_VUWS( "Unknown UWS version" ),
     W_WODM( "Incorrect ObsCore ID" ),
     W_ZRES( "Resolver not used?" ),
@@ -237,8 +285,10 @@ public enum FixedCode implements ReportCode {
     F_INTR( "Interrupted" ),
     F_MURL( "Bad URL" ),
     F_NODT( "Metadata lacks column/key detail" ),
+    F_NOPN( "No epn_core table" ),
     F_NOTB( "No obscore table" ),
     F_NOTM( "Earlier metadata stages not completed" ),
+    F_NOTP( "No obsplan table" ),
     F_NOUP( "No upload methods listed" ),
     F_SXER( "Unexpected SAX parse error" ),
     F_TBLA( "Table has no name" ),
@@ -260,14 +310,19 @@ public enum FixedCode implements ReportCode {
     I_EURL( "Reading examples document" ),
     I_EXA2( "Assume default query language" ),
     I_EXMP( "Example found" ),
+    I_EXVT( "Possible issues with examples RDFa vocab attribute" ),
     I_JOFI( "Job finished immediately" ),
     I_NODM( "No ObsCore tests" ),
     I_OCCP( "No ObsCore tests" ),
+    I_PNIX( "Starting epn_core tests" ),
+    I_PNSP( "Checking spatial-frame-specific coord metadata" ),
+    I_PNNS( "Non-standard epn_core columns" ),
     I_POPA( "Job POSTed" ),
     I_QGET( "Query GET URL" ),
     I_QJOB( "Submitted query URL" ),
     I_QSUB( "Submitted query" ),
     I_SCHM( "Use TAP_SCHEMA for metadata" ),
+    I_SVRI( "HTTP Server header value" ),
     I_TAPV( "TAP validation version" ),
     I_TMAX( "Table test count" ),
     I_TSNS( "Non-standard TAP_SCHEMA columns" ),
@@ -280,6 +335,9 @@ public enum FixedCode implements ReportCode {
     S_COLS( "ObsCore columns" ),
     S_FLGO( "Non-standard column flags" ),
     S_FLGS( "Standard column flags" ),
+    S_PCLS( "ObsLocTAP columns" ),
+    S_PNCS( "EPN-TAP columns" ),
+    S_PNCN( "Epn_core table count" ),
     S_QNUM( "Query count" ),
     S_QTIM( "Query time" ),
     S_SUMM( "Table metadata" ),
